Crate jwt_hmac

Crate jwt_hmac 

Structs

DecodedJwtHmac
A decoded JWT split into the pieces needed for payload extraction and signature verification.

Enums

Error

Functions

create
Generate a JWT token with the provided claims using the given secret
parse
Deserialize the claims struct from a jwt token

Type Aliases

Result